==> Useraccount0.01.tar.gz: Useraccount.py <==
import pymysql,json,time,random,json,re,requests

def Register(Nickname,Mobilephone,Password):
    conn = pymysql.connect(
        host='0.0.0.0',  
        port=3306,  
        user='数据库用户名', #修改为自己创建的Userdatasheet数据库的用户名
        password='数据库用户密码', #修改为自己创建的Userdatasheet数据库的用户密码
        db='数据库名字',
        charset='utf8'
    )
    UserID = int(time.time())
    data = (str(UserID),str(Nickname),str(Mobilephone),str(Password))
    sql = "INSERT INTO `Userdatasheet`(`UserID`, `Nickname`, `Mobilephone`, `Password`) VALUES  (%s, %s, %s, %s)"
    cursor = conn.cursor()
    cursor.execute(sql,data)
    conn.commit()
    conn.close()
    return "202"

def Vercodelogin(Mobilephone):
    kw = {'rphone':Mobilephone}
    response = requests.get("http://apps.fransuper.cn/VeriCodereq?", params = kw)
    return response.text

def Passwordlogin(Mobilephone,Password):
    conn = pymysql.connect(
        host='0.0.0.0',  
        port=3306,  
        user='数据库用户名', #修改为自己创建的Userdatasheet数据库的用户名
        password='数据库用户密码', #修改为自己创建的Userdatasheet数据库的用户密码
        db='数据库名字',
        charset='utf8'
    )
    sql = "SELECT `UserID`, `Nickname`, `Mobilephone`, `Password`, `Profile` FROM `Userdatasheet` WHERE Mobilephone = "+Mobilephone+""
    cursor = conn.cursor()
    cursor.execute(sql)
    conn.commit()
    res = cursor.fetchall()
    conn.close()
    a = res[0][3]
    if str(a) == str(Password):
        data = []
        a = {
            "UserID": res[0][0],
            "Nickname": res[0][1],
            "Mobilephone": res[0][2],
            "Profile": res[0][4]
        }
        data.append(a)  
    else:
        data = 404
    return data

==> Useraccount0.02.tar.gz: Useraccount.py <==
import pymysql,json,time,random,json,re,requests

def Register(Nickname,Mobilephone,Password):
    conn = pymysql.connect(
        host='0.0.0.0',  
        port=3306,  
        user='数据库用户名', #修改为自己创建的数据库用户名sheet数据库的用户名
        password='数据库用户密码', #修改为自己创建的数据库用户名sheet数据库的用户密码
        db='数据库名字',
        charset='utf8'
    )
    UserID = str(int(time.time()))
    data = (str(UserID),str(Nickname),str(Mobilephone),str(Password))
    sql = "INSERT INTO `Userdatasheet`(`UserID`, `Nickname`, `Mobilephone`, `Password`) VALUES  (%s, %s, %s, %s)"
    cursor = conn.cursor()
    cursor.execute(sql,data)
    conn.commit()
    conn.close()
    data = []
    a = {
        "UserID": UserID
    }
    data.append(a)
    return data

def Vercodelogin(Mobilephone):
    conn = pymysql.connect(
        host='0.0.0.0',  
        port=3306,  
        user='数据库用户名', #修改为自己创建的数据库用户名sheet数据库的用户名
        password='数据库用户密码', #修改为自己创建的数据库用户名sheet数据库的用户密码
        db='数据库名字',
        charset='utf8'
    )
    kw = {'rphone':Mobilephone}
    response = requests.get("http://apps.fransuper.cn/VeriCodereq?", params = kw)
    try:
        sql = "SELECT `UserID` FROM `Userdatasheet` WHERE Mobilephone = "+Mobilephone+""
        cursor = conn.cursor()
        cursor.execute(sql)
        conn.commit()
        res = cursor.fetchall()
        conn.close()
        UserID = res[0][0]
    except:
        data = []
        a = {
            "UserID": "UserIDNone",
            "VerCode": response.text
        }
        data.append(a)
        pass
    else:
        data = []
        a = {
            "UserID": res[0][0],
            "VerCode": response.text
        }
        data.append(a)
    return data

def Passwordlogin(Mobilephone,Password):
    conn = pymysql.connect(
        host='0.0.0.0',  
        port=3306,  
        user='数据库用户名', #修改为自己创建的数据库用户名sheet数据库的用户名
        password='数据库用户密码', #修改为自己创建的数据库用户名sheet数据库的用户密码
        db='数据库名字',
        charset='utf8'
    )
    sql = "SELECT `UserID`, `Nickname`, `Mobilephone`, `Password`, `Profile` FROM `Userdatasheet` WHERE Mobilephone = "+Mobilephone+""
    cursor = conn.cursor()
    cursor.execute(sql)
    conn.commit()
    res = cursor.fetchall()
    conn.close()
    a = res[0][3]
    if str(a) == str(Password):
        data = []
        a = {
            "UserID": res[0][0],
            "Nickname": res[0][1],
            "Mobilephone": res[0][2],
            "Profile": res[0][4]
        }
        data.append(a)  
    else:
        data = 404
    return data
